pub struct AllowedCountsCache { /* private fields */ }Expand description
Precomputed allowed counts tables for all shift values 0..=ANS_LOG_TAB_SIZE. These tables are deterministic (depend only on shift value) and can be computed once and reused across all histogram normalization calls.
Implementations