pub struct FileHeader {
pub width: u32,
pub height: u32,
pub metadata: ImageMetadata,
}Expand description
Complete JXL file header.
Fields
width: u32Image width in pixels.
height: u32Image height in pixels.
metadata: ImageMetadataImage metadata.
Implementations
Sourceimpl FileHeader
impl FileHeader
Sourcepub fn new_gray(width: u32, height: u32) -> Self
pub fn new_gray(width: u32, height: u32) -> Self
Creates a new file header for a grayscale image.
Sourcepub fn new_rgb_lossy(width: u32, height: u32) -> Self
pub fn new_rgb_lossy(width: u32, height: u32) -> Self
Creates a new file header for a lossy RGB image (VarDCT/XYB encoded).
Sourcepub fn write_signature(writer: &mut BitWriter) -> Result<()>
pub fn write_signature(writer: &mut BitWriter) -> Result<()>
Writes the JXL signature.