FrameCrop

Struct FrameCrop 

pub struct FrameCrop {
    pub x0: i32,
    pub y0: i32,
    pub width: u32,
    pub height: u32,
}
Crop rectangle for a frame within the canvas.

When set on a frame, the frame contains only the specified rectangular region. The decoder composites this region onto the persistent canvas using the frame’s blend mode. For Replace blending, only the crop rectangle is replaced; the rest of the canvas is unchanged.

Fields

x0: i32

X offset of the crop region within the canvas.

y0: i32

Y offset of the crop region within the canvas.

width: u32

Width of the crop region.

height: u32

Height of the crop region.