macro_rules! skip_without_binary {
($path:expr) => { ... };
}Expand description
Skip the current test if the given external binary is not available.
macro_rules! skip_without_binary {
($path:expr) => { ... };
}Skip the current test if the given external binary is not available.