pub enum GlobalModularState {
Huffman {
depths: Vec<u8>,
codes: Vec<u16>,
max_token: u32,
},
Ans {
code: OwnedAnsEntropyCode,
},
AnsWithTree {
code: OwnedAnsEntropyCode,
tree: Tree,
wp_params: WeightedPredictorParams,
},
}Expand description
Result of writing the global modular section. Contains the entropy codes needed to encode pixel data in group sections.
Variants
Huffman
Huffman entropy coding state.
Fields
Ans
ANS entropy coding state (single-context gradient tree).
Fields

code: OwnedAnsEntropyCodeThe ANS entropy code (distributions, context map, etc.)
AnsWithTree
ANS entropy coding with learned MA tree (multi-context).
Fields

code: OwnedAnsEntropyCodeThe ANS entropy code (multiple distributions, context map).

wp_params: WeightedPredictorParamsWP parameters used during tree learning and residual collection.